Registers as an RStudio/Positron addin. Builds a client from the user's
settings and launches codeagent_app(). Optionally pre-fills the first
user message with any text currently selected in the source editor.
Registers as an RStudio/Positron addin. Builds a client from the user's
settings and launches codeagent_app(). Optionally pre-fills the first
user message with any text currently selected in the source editor.