Fetches an authorized public HTTP(S) URL directly. DNS answers are validated and the selected public IP is pinned for the connection; redirects are re-authorized one hop at a time.
Value
An ellmer::tool() object.
Fetches an authorized public HTTP(S) URL directly. DNS answers are validated and the selected public IP is pinned for the connection; redirects are re-authorized one hop at a time.
An ellmer::tool() object.